#!/usr/bin/python3
from distutils.core import setup
setup(name='sylcount',
	  version='1.0.0',
	  description="Count syllables in a word, real or made-up.",
	  author="Bede Kelly",
	  author_email="bedekelly97@gmail.com",
	  url="https://github.com/bedekelly/sylcount",
	  provides=['sylcount'],
	  scripts=['sylcount'],
	  classifiers=[
	  	"Natural Language :: English",
	  	"Operating System :: OS Independent",
	  	"Programming Language :: Python :: 3",
	  	"Programming Language :: Python :: Implementation :: CPython",
	  	"Topic :: Utilities"
	  	])
